import click

from deploifai.context import (
    pass_deploifai_context_obj,
    DeploifaiContextObj,
    project_found,
)


@click.command()
@pass_deploifai_context_obj
@project_found
def info(context: DeploifaiContextObj):
    """
    Get information about a dataset
    """
    deploifai_api = context.api

    storage_details = deploifai_api.get_data_storage_info(data_storage_id)

    project_id = storage_details["project"]["id"]
    cloud_provider = storage_details["cloudProviderYodaConfig"]["provider"]
    container = storage_details["containers"][0]
    container_name = container["directoryName"]

    if cloud_provider == "AWS":
        click.secho("AWS dataset CLI support is coming soon.", fg="blue")

    elif cloud_provider == "AZURE":
        storage_account_name = storage_details["cloudProviderYodaConfig"][
            "azureConfig"
        ]["storageAccount"]

        click.secho("Deploifai Storage ID: {}".format(data_storage_id), fg="green")
        click.secho(
            "https://deploif.ai/dashboard/{username}/projects/{project_id}/datasets/{data_storage_id}\n".format(
                username=context.global_config["AUTH"]["username"],
                project_id=project_id,
                data_storage_id=data_storage_id,
            ),
            underline=True,
            fg="green",
        )
        click.secho("Azure Storage Account", bold=True, fg="blue", underline=True)
        click.secho("Storage Account Name: {}".format(storage_account_name), fg="blue")
        click.secho("Container Name: {}".format(container_name), fg="blue")
        click.secho(
            "\nYou could use the Azure CLI to list all the blobs in your container on Azure:",
            underline=True,
        )
        click.secho(
            "az storage blob list -c {container_name} --account-name {storage_account_name}".format(
                storage_account_name=storage_account_name, container_name=container_name
            ),
            fg="yellow",
        )

    elif cloud_provider == "GCP":
        click.secho("GCP dataset CLI support is coming soon.", fg="blue")



import click
from PyInquirer import prompt
from deploifai.utilities.cloud_profile import Provider
from deploifai.context import (
    pass_deploifai_context_obj,
    DeploifaiContextObj,
    is_authenticated,
)
from deploifai.api import DeploifaiAPIError


@click.command()
@click.argument("name")
@pass_deploifai_context_obj
@is_authenticated
def create(context: DeploifaiContextObj, name: str):
    """
    Create a new cloud profile
    """
    deploifai_api = context.api

    command_workspace = context.global_config["WORKSPACE"]["username"]

    try:
        cloud_profiles = deploifai_api.get_cloud_profiles(workspace=command_workspace)
    except DeploifaiAPIError as err:
        click.secho(err, fg="red")
        return

    existing_names = [cloud_profile.name for cloud_profile in cloud_profiles]

    if name in existing_names:
        click.echo(click.style("Cloud profile name taken. Existing names: ", fg="red") + ' '.join(existing_names))
        raise click.Abort()

    provider = prompt(
        {
            "type": "list",
            "name": "provider",
            "message": "Choose a provider for the new cloud profile",
            "choices": [{"name": provider.value, "value": provider} for provider in Provider]
        }
    )["provider"]

    cloud_credentials = {}
    if provider == Provider.AWS:
        cloud_credentials["awsAccessKey"] = prompt(
            {
                "type": "input",
                "name": "awsAccessKey",
                "message": "AWS Access Key ID (We'll keep these secured and encrypted)",
            }
        )["awsAccessKey"]
        cloud_credentials["awsSecretAccessKey"] = prompt(
            {
                "type": "input",
                "name": "awsSecretAccessKey",
                "message": "AWS Secret Access Key (We'll keep these secured and encrypted)",
            }
        )["awsSecretAccessKey"]
    elif provider == Provider.AZURE:
        cloud_credentials["azureSubscriptionId"] = prompt(
            {
                "type": "input",
                "name": "azureSubscriptionId",
                "message": "Azure Account Subscription ID (We'll keep these secured and encrypted)",
            }
        )["azureSubscriptionId"]
        cloud_credentials["azureTenantId"] = prompt(
            {
                "type": "input",
                "name": "azureTenantId",
                "message": "Azure Active Directory Tenant ID (We'll keep these secured and encrypted)",
            }
        )["azureTenantId"]
        cloud_credentials["azureClientId"] = prompt(
            {
                "type": "input",
                "name": "azureClientId",
                "message": "Azure Client ID (We'll keep these secured and encrypted)",
            }
        )["azureClientId"]
        cloud_credentials["azureClientSecret"] = prompt(
            {
                "type": "input",
                "name": "azureClientSecret",
                "message": "Azure Client Secret / Password (We'll keep these secured and encrypted)",
            }
        )["azureClientSecret"]
    else:
        cloud_credentials["gcpProjectId"] = prompt(
            {
                "type": "input",
                "name": "gcpProjectId",
                "message": "GCP Project ID (We'll keep these secured and encrypted)",
            }
        )["gcpProjectId"]

        gcp_service_account_key_file = prompt(
            {
                "type": "input",
                "name": "gcp_service_account_key_file",
                "message": "File path for the GCP Service Account Key File (We'll keep these secured and encrypted)",
            }
        )["gcp_service_account_key_file"]

        try:
            with open(gcp_service_account_key_file) as gcp_service_account_key_json:
                cloud_credentials["gcpServiceAccountKey"] = gcp_service_account_key_json.read()
        except FileNotFoundError:
            click.secho("File not found. Please input the correct file path.", fg="red")
            raise click.Abort()

    context.debug_msg(cloud_credentials)
    try:
        cloud_profile_fragment = """
        fragment cloud_profile on CloudProfile {
            id
        }
        """
        _ = deploifai_api.create_cloud_profile(
            provider,
            name,
            cloud_credentials,
            command_workspace,
            cloud_profile_fragment
        )
    except DeploifaiAPIError as err:
        click.secho(err, fg="red")
        raise click.Abort()

    click.secho(f"Successfully created a new cloud profile named {name}.", fg="green")
